@@ -3,7 +3,7 @@
 # Univention Management Console
 #  UMC server
 #
-# SPDX-FileCopyrightText: 2006-2025 Univention GmbH
+# SPDX-FileCopyrightText: 2006-2026 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 
@@ -54,40 +54,45 @@ class Application(TApplication):
 
     def __init__(self, **settings):
         tornado.locale.load_gettext_translations('/usr/share/locale', 'univention-management-console')
+
+        root_path = os.environ.get('UMC_ROOT_PATH', '').strip().strip('/')
+        root_path = f'/{root_path}' if root_path else ''
+        self.root_path = root_path
+
         super().__init__([
-            url(r'/', Index, name='index'),
-            (r'/auth/?', Auth),
-            (r'/upload/?', Upload),
-            (r'/(upload)/(.+)', Command),
-            (r'/(command)/(.+)', Command),
-            (r'/get/session-info', SessionInfo),
-            (r'/get/ipaddress', GetIPAddress),
-            (r'/get/ucr', UCR),
-            (r'/get/meta', Meta),
-            (r'/get/info', Info),
-            (r'/get/newsession', NewSession),
-            (r'/get/modules', Modules),
-            (r'/get/categories', Categories),
-            (r'/get/user/preferences', UserPreferences),
-            (r'/get/hosts', Hosts),
-            (r'/set/?', Set),
-            (r'/set/password', SetPassword),
-            (r'/set/locale', SetLocale),
-            (r'/set/user/preferences', SetUserPreferences),
-            (r'/saml/', SamlACS),
-            (r'/saml/metadata', SamlMetadata),
-            (r'/saml/slo/?', SamlSingleLogout),
-            (r'/saml/logout/?', SamlLogout),
-            (r'/saml/iframe/?', SamlIframeACS),
-            url(r'/oidc/', OIDCLogin, name='oidc-login'),
-            url(r'/oidc/logout', OIDCLogout, name='oidc-logout'),
-            url(r'/oidc/frontchannel-logout', OIDCFrontchannelLogout, name='frontchannel-logout'),
-            url(r'/oidc/backchannel-logout', OIDCBackchannelLogout, name='backchannel-logout'),
-            url(r'/oidc/logout-done', OIDCLogoutFinished, name='oidc-logout-done'),
-            url(r'/oidc/.well-known/oauth-client', OIDCMetadata),
-            url(r'/logout-sse', SSELogoutNotifer),
-            (r'/logout/?', Logout),
-            (r'()/(.+)', Command),
+            url(rf'{root_path}/', Index, name='index'),
+            (rf'{root_path}/auth/?', Auth),
+            (rf'{root_path}/upload/?', Upload),
+            (rf'{root_path}/(upload)/(.+)', Command),
+            (rf'{root_path}/(command)/(.+)', Command),
+            (rf'{root_path}/get/session-info', SessionInfo),
+            (rf'{root_path}/get/ipaddress', GetIPAddress),
+            (rf'{root_path}/get/ucr', UCR),
+            (rf'{root_path}/get/meta', Meta),
+            (rf'{root_path}/get/info', Info),
+            (rf'{root_path}/get/newsession', NewSession),
+            (rf'{root_path}/get/modules', Modules),
+            (rf'{root_path}/get/categories', Categories),
+            (rf'{root_path}/get/user/preferences', UserPreferences),
+            (rf'{root_path}/get/hosts', Hosts),
+            (rf'{root_path}/set/?', Set),
+            (rf'{root_path}/set/password', SetPassword),
+            (rf'{root_path}/set/locale', SetLocale),
+            (rf'{root_path}/set/user/preferences', SetUserPreferences),
+            (rf'{root_path}/saml/', SamlACS),
+            (rf'{root_path}/saml/metadata', SamlMetadata),
+            (rf'{root_path}/saml/slo/?', SamlSingleLogout),
+            (rf'{root_path}/saml/logout/?', SamlLogout),
+            (rf'{root_path}/saml/iframe/?', SamlIframeACS),
+            url(rf'{root_path}/oidc/', OIDCLogin, name='oidc-login'),
+            url(rf'{root_path}/oidc/logout', OIDCLogout, name='oidc-logout'),
+            url(rf'{root_path}/oidc/frontchannel-logout', OIDCFrontchannelLogout, name='frontchannel-logout'),
+            url(rf'{root_path}/oidc/backchannel-logout', OIDCBackchannelLogout, name='backchannel-logout'),
+            url(rf'{root_path}/oidc/logout-done', OIDCLogoutFinished, name='oidc-logout-done'),
+            url(rf'{root_path}/oidc/.well-known/oauth-client', OIDCMetadata),
+            url(rf'{root_path}/logout-sse', SSELogoutNotifer),
+            (rf'{root_path}/logout/?', Logout),
+            (rf'{root_path}()/(.+)', Command),
         ], default_handler_class=Nothing, **settings)
 
         SamlACS.reload()
